==> bplan-base-globals-1.8.1-643a21.zip: database/migrations/1000_01_01_000002.globals.create_access_points_table.php <==
<?php
/**
 * Migration Class
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-modules/visitor-management
 * @subpackage  Migrations
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */


use BplanBase\CodeGenerator\Loaders\CodeGenerator;
use BplanBase\Globals\Enums\AccessPointType;
use BplanBase\Globals\Enums\AccessPointDirection;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;


/**
 * Migration Class
 *
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 */
return new class extends Migration
{


    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('access_points');

    } // down()


    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('access_points', function (Blueprint $Table) {
            $Table->id();
            $Table->boolean('active')->default(1);

            $Table->timestamps();
            $Table->softDeletes('deleted_at');

            $Table->enum('direction', array_column(AccessPointDirection::cases(), 'name'))->default(AccessPointDirection::Moot->name);
            $Table->enum('access_point_type', array_column(AccessPointType::cases(), 'name'));
            $Table->string('label', 100);
            $Table->string('token', 6)->comment('Ein eindeutiger Bezeichner für jeden AccessPoint. Aufbau: AP#### ("EP" gefolgt von 4 Ziffern). Bei Kamera-/Schrankensystemen entspricht die Zahl dem verwendeten Port.');

            $Table->unique('token', 'access_points_UK_token');

            new CodeGenerator($Table, [
                'columns' => [
                    'active' => [
                        'sortable' => true,
                    ],
                    'direction' => [
                        'rules' => [
                            'required',
                            'Rule::enum(AccessPointDirection::class)'
                        ],
                        'sortable' => true,
                    ],
                    'access_point_type' => [
                        'rules' => [
                            'required',
                            'Rule::enum(AccessPointType::class)'
                        ],
                        'sortable' => true,
                    ],
                    'label' => [
                        'sortable' => true,
                    ],
                ],
                'routing' => [
                    'terminal' => 'readOnly',
                ],
                'uses' => [
                    'jsonapi.request' => [
                        'BplanModules\\VisitorManagement\\Enums\\AccessPointType',
                        'Illuminate\\Validation\\Rule',
                    ],
                    'laravel.repository' => [
                        'BplanModules\\VisitorManagement\\Enums\\AccessPointDirection',
                    ],
                ],
            ]);

        });
    } // up()


};

==> bplan-base-globals-1.14.1-2bb234.zip: database/migrations/0000_01_01_000100.globals.create_access_points_table.php <==
<?php
/**
 * Migration Class
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Migrations
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <https://www.bplan-solutions.de/>
 * /Δ\
 */


use BplanBase\CodeGenerator\Loaders\CodeGenerator;
use BplanBase\Globals\Enums\AccessPointType;
use BplanBase\Globals\Enums\AccessPointDirection;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;


/**
 * Migration Class
 *
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 */
return new class extends Migration
{


    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('access_points');

    } // down()


    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('access_points', function (Blueprint $Table) {
            $Table->id();
            $Table->uuid('uuid');
            $Table->boolean('active')->default(1);

            $Table->timestamp('created_at');
            $Table->softDeletes('deleted_at');
            $Table->timestamp('updated_at');

            $Table->enum('direction', array_column(AccessPointDirection::cases(), 'name'))->default(AccessPointDirection::Moot->name);
            $Table->enum('access_point_type', array_column(AccessPointType::cases(), 'name'));
            $Table->string('label', 100);
            $Table->string('token', 6)->comment('Ein eindeutiger Bezeichner für jeden AccessPoint. Aufbau: AP#### ("EP" gefolgt von 4 Ziffern). Bei Kamera-/Schrankensystemen entspricht die Zahl dem verwendeten Port.');

            $Table->unique('token', 'access_points_UK_token');

            new CodeGenerator($Table, [
                'columns' => [
                    'active' => [
                        'sortable' => true,
                    ],
                    'direction' => [
                        'rules' => [
                            'required',
                            'Rule::enum(AccessPointDirection::class)'
                        ],
                        'sortable' => true,
                    ],
                    'access_point_type' => [
                        'rules' => [
                            'required',
                            'Rule::enum(AccessPointType::class)'
                        ],
                        'sortable' => true,
                    ],
                    'label' => [
                        'sortable' => true,
                    ],
                ],
                'routing' => [
                    'terminal' => 'readOnly',
                ],
                'traits' => [
                    'laravel.model' => [
                        'BplanBase\\Globals\Traits\\HasActiveScope',
                        'BplanBase\\Globals\Traits\\HasOrderedScope',
                        'Laravel\\Sanctum\\HasApiTokens',
                    ],
                ],
                'uses' => [
                    'jsonapi.request' => [
                        'BplanModules\\VisitorManagement\\Enums\\AccessPointType',
                        'Illuminate\\Validation\\Rule',
                    ],
                    'laravel.model' => [
                        'BplanBase\\Globals\\Scopes\\TenantScope'
                    ],
                    'laravel.repository' => [
                        'BplanModules\\VisitorManagement\\Enums\\AccessPointDirection',
                    ],
                ],
            ]);

        });
    } // up()


};
